# -*- coding: utf-8 -*-
# Generated by Django 1.9.4 on 2016-07-22 10:56
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('pinax_events', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='event',
            name='title',
            field=models.CharField(default='', max_length=200),
            preserve_default=False,
        ),
    ]



import uuid

from django.db import models
from django.utils import timezone

import markdown
from imagekit.models import ImageSpecField


def image_upload_to(instance, filename):
    uid = str(uuid.uuid4())
    ext = filename.split(".")[-1].lower()
    return "event-images/{}/{}.{}".format(instance.pk, uid, ext)


class Event(models.Model):

    image = models.ImageField(upload_to=image_upload_to, blank=True)
    secondary_image = models.ImageField(upload_to=image_upload_to, blank=True)
    title = models.CharField(max_length=200)
    url = models.TextField(blank=True)
    where = models.CharField(max_length=200)
    what = models.TextField()
    what_html = models.TextField(blank=True, editable=False)
    start_date = models.DateField()
    end_date = models.DateField()

    published_at = models.DateTimeField(default=timezone.now)
    created_at = models.DateTimeField(default=timezone.now)

    image_thumb = ImageSpecField(source="image", id="pinax_events:image:thumb")
    secondary_image_thumb = ImageSpecField(source="secondary_image", id="pinax_events:secondary_image:thumb")

    def save(self, *args, **kwargs):
        if self.what:
            self.what_html = markdown.markdown(self.what)
        return super(Event, self).save(*args, **kwargs)

    @classmethod
    def upcoming(cls):
        now = timezone.now()
        return cls.objects.filter(
            published_at__lte=now
        ).filter(
            end_date__gte=now.date()
        )



from datetime import timedelta

from django.test import TestCase
from django.utils import timezone

from pinax.events.models import Event
from pinax.events.templatetags.pinax_events_tags import events


class Tests(TestCase):

    def test_html_generated_on_save(self):
        event = Event.objects.create(
            title="Test Event",
            where="Nashville, TN",
            what="### The Main Event\n\n* Item Number 1\n* Item Number 2",
            start_date=timezone.now().date(),
            end_date=timezone.now().date()
        )
        self.assertEquals(event.what_html, "<h3>The Main Event</h3>\n<ul>\n<li>Item Number 1</li>\n<li>Item Number 2</li>\n</ul>")

    def test_upcoming(self):
        start = timezone.now().date()
        end = (timezone.now() + timedelta(days=5)).date()
        Event.objects.create(
            title="Test Event",
            where="Nashville, TN",
            what="### The Main Event\n\n* Item Number 1\n* Item Number 2",
            start_date=start,
            end_date=end
        )
        self.assertEquals(Event.upcoming().count(), 1)

    def test_events_tag(self):
        start = timezone.now().date()
        end = (timezone.now() + timedelta(days=5)).date()
        Event.objects.create(
            title="Test Event",
            where="Nashville, TN",
            what="### The Main Event\n\n* Item Number 1\n* Item Number 2",
            start_date=start,
            end_date=end
        )
        self.assertEquals(events().count(), 1)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.8 on 2016-07-22 10:21
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image', models.ImageField(blank=True, upload_to=b'event-images')),
                ('where', models.CharField(max_length=200)),
                ('what', models.TextField()),
                ('what_html', models.TextField(blank=True, editable=False)),
                ('start_date', models.DateField()),
                ('end_date', models.DateField()),
                ('published_at', models.DateTimeField(default=django.utils.timezone.now)),
                ('created_at', models.DateTimeField(default=django.utils.timezone.now)),
            ],
        ),
    ]



from django.apps import AppConfig as BaseAppConfig
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from imagekit import register

from .utils import load_path_attr


class AppConfig(BaseAppConfig):

    name = "pinax.events"
    label = "pinax_events"
    verbose_name = _("Pinax Events")

    def ready(self):
        image_path = getattr(
            settings,
            "PINAX_EVENTS_IMAGE_THUMBNAIL_SPEC",
            "pinax.events.specs.ImageThumbnail"
        )
        secondary_image_path = getattr(
            settings,
            "PINAX_EVENTS_SECONDARY_IMAGE_THUMBNAIL_SPEC",
            "pinax.events.specs.SecondaryImageThumbnail"
        )

        image_spec_class = load_path_attr(image_path)
        secondary_image_spec_class = load_path_attr(secondary_image_path)

        register.generator("pinax_events:image:thumb", image_spec_class)
        register.generator("pinax_events:secondary_image:thumb", secondary_image_spec_class)



import importlib

from django.core.exceptions import ImproperlyConfigured


def load_path_attr(path):
    i = path.rfind(".")
    module, attr = path[:i], path[i + 1:]
    try:
        mod = importlib.import_module(module)
    except ImportError as e:
        raise ImproperlyConfigured("Error importing {0}: '{1}'".format(module, e))
    try:
        attr = getattr(mod, attr)
    except AttributeError:
        raise ImproperlyConfigured("Module '{0}' does not define a '{1}'".format(module, attr))
    return attr



from django import template
from django.utils import timezone

from ..models import Event

register = template.Library()


@register.simple_tag
def events():
    """
    Usage:
        {% events as var %}
    """
    return Event.objects.filter(published_at__lte=timezone.now()).order_by("-published_at")



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-05 11:44
from __future__ import unicode_literals

from django.db import migrations, models
import pinax.events.models


class Migration(migrations.Migration):

    dependencies = [
        ('pinax_events', '0003_event_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='event',
            name='secondary_image',
            field=models.ImageField(blank=True, upload_to=pinax.events.models.image_upload_to),
        ),
        migrations.AlterField(
            model_name='event',
            name='image',
            field=models.ImageField(blank=True, upload_to=pinax.events.models.image_upload_to),
        ),
    ]



from imagekit import ImageSpec
from pilkit.processors import ResizeToFit, SmartResize


class ImageThumbnail(ImageSpec):
    processors = [ResizeToFit(width=168, height=None)]
    format = "JPEG"
    options = {"quality": 75}


class SecondaryImageThumbnail(ImageSpec):
    processors = [SmartResize(405, 250)]
    format = "JPEG"
    options = {"quality": 75}
